@@ -95,7 +95,7 @@ Dancer2::Session::CHI - Dancer 2 session storage with CHI backend
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -128,6 +128,14 @@ parameters to CHI.
 This is heavily based on L<Dancer2::Session::Memcached> by David Golden and
 Yanick Champoux.
 
+=head2 Contributors
+
+The following people have contributes to C<Dancer2::Session::CHI> in some way,
+either through bug reports, code, suggestions, or moral support:
+
+andk
+Mohammad S Anwar
+
 =head1 AUTHOR
 
 Jason A. Crome <cromedome@cpan.org>
